@@ -2,7 +2,6 @@ import datetime
 import sys
 from decimal import Decimal
 
-import pymysql
 import pytest
 import pytest_mysql.factories
 import pytest_postgresql.factories
@@ -20,8 +19,6 @@ from iker.common.utils.funcutils import unique_returns
 from iker.common.utils.randutils import randomizer
 from iker.common.utils.testutils import nested_approx
 
-pymysql.install_as_MySQLdb()
-
 fixture_mysql_test_proc = pytest_mysql.factories.mysql_proc(host="localhost",
                                                             port=randomizer().next_int(9900, 10000),
                                                             user="root")
